#include "geometry_shapes.h"
#include "brush_utils.h"
#include "sgg/graphics.h"

// Μέγεθος παραθύρου
const float WINDOW_WIDTH = 800;
const float WINDOW_HEIGHT = 600;

// Συνάρτηση για τη σχεδίαση στο παράθυρο
void draw() {
    graphics::Brush brush;

    // Δημιουργία ανοιχτού γκρι χρώματος για το φόντο
    brush_utils::setFillColor(brush, 0.9f, 0.9f, 0.9f);
    graphics::drawRect(WINDOW_WIDTH / 2, WINDOW_HEIGHT / 2, WINDOW_WIDTH, WINDOW_HEIGHT, brush);

    // Δημιουργία χρώματος για τα σχήματα (μπλε)
    brush_utils::setFillColor(brush, 0.2f, 0.6f, 0.8f);

    // Σχεδίαση τετραγώνου
    // Τοποθεσία: (100, 100), Πλευρά: 50
    GeometryShapes::drawSquare(100, 100, 50, brush);

    // Σχεδίαση παραλληλογράμμου
    // Τοποθεσία: (250, 100), Πλάτος: 80, Ύψος: 50
    GeometryShapes::drawRectangle(250, 100, 80, 50, brush);

    // Σχεδίαση ρόμβου
    // Τοποθεσία: (400, 100), Διαγώνιος 1: 80, Διαγώνιος 2: 50
    GeometryShapes::drawRhombus(400, 100, 80, 50, brush);

    // Σχεδίαση ορθογώνιου παραλληλογράμμου
    // Τοποθεσία: (550, 100), Πλάτος: 100, Ύψος: 50
    GeometryShapes::drawParallelogram(550, 100, 100, 50, brush);

    // Σχεδίαση τραπεζίου
    // Τοποθεσία: (700, 100), Πάνω Βάση: 60, Κάτω Βάση: 100, Ύψος: 50
    GeometryShapes::drawTrapezoid(700, 100, 60, 100, 50, brush);

    // Αλλαγή χρώματος για τα τρίγωνα (κόκκινο)
    brush_utils::setFillColor(brush, 0.8f, 0.3f, 0.5f);

    // Σχεδίαση τριγώνου
    // Κορυφές: (100, 250), (150, 250), (125, 200)
    GeometryShapes::drawTriangle(100, 250, 150, 250, 125, 200, brush);

    // Σχεδίαση ορθογώνιου τριγώνου
    // Τοποθεσία: (250, 250), Βάση: 50, Ύψος: 30
    GeometryShapes::drawRightTriangle(250, 250, 50, 30, brush);

    // Σχεδίαση ισοσκελούς τριγώνου
    // Τοποθεσία: (400, 250), Βάση: 60, Ύψος: 40
    GeometryShapes::drawIsoscelesTriangle(400, 250, 60, 40, brush);

    // Σχεδίαση ισοπλεύρου τριγώνου
    // Τοποθεσία: (550, 250), Πλευρά: 50
    GeometryShapes::drawEquilateralTriangle(550, 250, 50, brush);

    // Σχεδίαση κανονικού πενταγώνου
    // Τοποθεσία: (700, 250), Ακτίνα: 30, Πλευρές: 5
    GeometryShapes::drawRegularPolygon(700, 250, 5, 30, brush);
}

// Συνάρτηση main
int main() {
    // Δημιουργία παραθύρου
    graphics::createWindow(WINDOW_WIDTH, WINDOW_HEIGHT, "Example of Geometry Shapes and Brush Utilities");

    // Ορισμός της συνάρτησης σχεδίασης
    graphics::setDrawFunction(draw);

    // Εκκίνηση του κυκλώματος μηνυμάτων
    graphics::startMessageLoop();

    return 0;
}